@@ -930,6 +930,14 @@ public interface Context extends Container, ContextBind {
     public void addWrapperListener(String listener);
 
 
+    /**
+     * Factory method to create and return a new InstanceManager
+     * instance. This can be used for framework integration or easier
+     * configuration with custom Context implementations.
+     * @return the instance manager
+     */
+    public InstanceManager createInstanceManager();
+
     /**
      * Factory method to create and return a new Wrapper instance, of
      * the Java implementation class appropriate for this Context
@@ -1385,6 +1393,7 @@ public interface Context extends Container, ContextBind {
      */
     public JspConfigDescriptor getJspConfigDescriptor();
 
+
     /**
      * Set the JspConfigDescriptor for this context.
      * A null value indicates there is not JSP configuration.
@@ -1393,6 +1402,7 @@ public interface Context extends Container, ContextBind {
      */
     public void setJspConfigDescriptor(JspConfigDescriptor descriptor);
 
+
     /**
      * Add a ServletContainerInitializer instance to this web application.
      *
@@ -1403,6 +1413,7 @@ public interface Context extends Container, ContextBind {
     public void addServletContainerInitializer(
             ServletContainerInitializer sci, Set<Class<?>> classes);
 
+
     /**
      * Is this Context paused whilst it is reloaded?
      *
@@ -1418,6 +1429,7 @@ public interface Context extends Container, ContextBind {
      */
     boolean isServlet22();
 
+
     /**
      * Notification that Servlet security has been dynamically set in a
      * {@link javax.servlet.ServletRegistration.Dynamic}
@@ -1473,7 +1485,7 @@ public interface Context extends Container, ContextBind {
     /**
      * @return The version of this web application, used to differentiate
      * different versions of the same web application when using parallel
-     * deployment.
+     * deployment. If not specified, defaults to the empty string.
      */
     public String getWebappVersion();
 
@@ -1871,4 +1883,26 @@ public interface Context extends Container, ContextBind {
 
 
     public void decrementInProgressAsyncCount();
+
+
+    /**
+     * Configure whether Tomcat will attempt to create an upload target used by
+     * this web application if it does not exist when the web application
+     * attempts to use it.
+     *
+     * @param createUploadTargets {@code true} if Tomcat should attempt to
+     *          create the upload target, otherwise {@code false}
+     */
+    public void setCreateUploadTargets(boolean createUploadTargets);
+
+
+    /**
+     * Will Tomcat attempt to create an upload target used by this web
+     * application if it does not exist when the web application attempts to use
+     * it?
+     *
+     * @return {@code true} if Tomcat will attempt to create an upload target
+     *         otherwise {@code false}
+     */
+    public boolean getCreateUploadTargets();
 }
