@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -30,7 +30,6 @@ import org.apache.tools.ant.BuildException;
  * supported by the Tomcat manager application.
  *
  * @author Vivek Chopra
- *
  */
 public class JMXSetTask extends AbstractCatalinaTask {
 
@@ -52,7 +51,7 @@ public class JMXSetTask extends AbstractCatalinaTask {
     protected String value     = null;
 
     // Public Methods
-    
+
     /**
      * Get method for the bean name
      * @return Bean name
@@ -106,6 +105,7 @@ public class JMXSetTask extends AbstractCatalinaTask {
      *
      * @exception BuildException if an error occurs
      */
+    @Override
     public void execute() throws BuildException {
         super.execute();
         if (bean == null || attribute == null || value == null) {
@@ -114,10 +114,10 @@ public class JMXSetTask extends AbstractCatalinaTask {
         }
         log("Setting attribute " + attribute +
                             " in bean " + bean +
-                            " to " + value); 
+                            " to " + value);
         try {
-            execute("/jmxproxy/?set=" + URLEncoder.encode(bean, getCharset()) 
-                    + "&att=" + URLEncoder.encode(attribute, getCharset()) 
+            execute("/jmxproxy/?set=" + URLEncoder.encode(bean, getCharset())
+                    + "&att=" + URLEncoder.encode(attribute, getCharset())
                     + "&val=" + URLEncoder.encode(value, getCharset()));
         } catch (UnsupportedEncodingException e) {
             throw new BuildException
