@@ -250,7 +250,7 @@ public class FarmWarDeployer extends ClusterListener
                                     "farmWarDeployer.servicingDeploy",
                                     contextName, name));
                     } catch (Exception ex) {
-                        log.error(ex);
+                        log.error(sm.getString("farmWarDeployer.fileMessageError"), ex);
                     } finally {
                         removeFactory(fmsg);
                     }
@@ -278,7 +278,7 @@ public class FarmWarDeployer extends ClusterListener
                                 "farmWarDeployer.servicingUndeploy",
                                 contextName));
                 } catch (Exception ex) {
-                    log.error(ex);
+                    log.error(sm.getString("farmWarDeployer.undeployMessageError"), ex);
                 }
             }
         } catch (java.io.IOException x) {
@@ -746,7 +746,7 @@ public class FarmWarDeployer extends ClusterListener
         }
 
         try (java.io.FileInputStream is = new java.io.FileInputStream(from);
-                java.io.FileOutputStream os = new java.io.FileOutputStream(to, false);) {
+                java.io.FileOutputStream os = new java.io.FileOutputStream(to, false)) {
             byte[] buf = new byte[4096];
             while (true) {
                 int len = is.read(buf);
