@@ -174,19 +174,31 @@ public class StatusTransformer {
 
                 writer.print("<p>");
                 writer.print( args[0] );
+                writer.print(' ');
                 writer.print(formatSize(Long.valueOf(result[0]), true));
-                writer.print(" " + args[1]);
+                writer.print(' ');
+                writer.print(args[1]);
+                writer.print(' ');
                 writer.print(formatSize(Long.valueOf(result[1]), true));
-                writer.print(" " + args[2]);
+                writer.print(' ');
+                writer.print(args[2]);
+                writer.print(' ');
                 writer.print(formatSize(Long.valueOf(result[2]), true));
-                writer.print(" " + args[3]);
+                writer.print(' ');
+                writer.print(args[3]);
+                writer.print(' ');
                 writer.print(formatSize(Long.valueOf(result[3]), true));
-                writer.print(" " + args[4]);
+                writer.print(' ');
+                writer.print(args[4]);
+                writer.print(' ');
                 writer.print(Long.valueOf(result[6]));
                 writer.print("<br>");
-                writer.print(" " + args[5]);
+                writer.print(args[5]);
+                writer.print(' ');
                 writer.print(formatTime(Long.valueOf(result[11] / 1000), true));
-                writer.print(" " + args[6]);
+                writer.print(' ');
+                writer.print(args[6]);
+                writer.print(' ');
                 writer.print(formatTime(Long.valueOf(result[12] / 1000), true));
                 writer.print("</p>");
             } else if (mode == 1){
@@ -219,12 +231,17 @@ public class StatusTransformer {
 
             writer.print("<p>");
             writer.print( args[0] );
+            writer.print(' ');
             writer.print(formatSize(
                     Long.valueOf(Runtime.getRuntime().freeMemory()), true));
-            writer.print(" " + args[1] );
+            writer.print(' ');
+            writer.print(args[1]);
+            writer.print(' ');
             writer.print(formatSize(
                     Long.valueOf(Runtime.getRuntime().totalMemory()), true));
-            writer.print(" " + args[2] );
+            writer.print(' ');
+            writer.print(args[2]);
+            writer.print(' ');
             writer.print(formatSize(
                     Long.valueOf(Runtime.getRuntime().maxMemory()), true));
             writer.print("</p>");
@@ -301,12 +318,19 @@ public class StatusTransformer {
 
             writer.print("<p>");
             writer.print( args[0] );
+            writer.print(' ');
             writer.print(mBeanServer.getAttribute(tpName, "maxThreads"));
-            writer.print(" " + args[1]);
+            writer.print(' ');
+            writer.print(args[1]);
+            writer.print(' ');
             writer.print(mBeanServer.getAttribute(tpName, "currentThreadCount"));
-            writer.print(" " + args[2]);
+            writer.print(' ');
+            writer.print(args[2]);
+            writer.print(' ');
             writer.print(mBeanServer.getAttribute(tpName, "currentThreadsBusy"));
-            writer.print(" " + args[3]);
+            writer.print(' ');
+            writer.print(args[3]);
+            writer.print(' ');
             writer.print(mBeanServer.getAttribute(tpName, "keepAliveCount"));
 
             writer.print("<br>");
@@ -327,19 +351,30 @@ public class StatusTransformer {
             }
 
             writer.print( args[4] );
+            writer.print(' ');
             writer.print(formatTime(mBeanServer.getAttribute
                                     (grpName, "maxTime"), false));
-            writer.print(" " + args[5]);
+            writer.print(' ');
+            writer.print(args[5]);
+            writer.print(' ');
             writer.print(formatTime(mBeanServer.getAttribute
                                     (grpName, "processingTime"), true));
-            writer.print(" " + args[6]);
+            writer.print(' ');
+            writer.print(args[6]);
+            writer.print(' ');
             writer.print(mBeanServer.getAttribute(grpName, "requestCount"));
-            writer.print(" " + args[7]);
+            writer.print(' ');
+            writer.print(args[7]);
+            writer.print(' ');
             writer.print(mBeanServer.getAttribute(grpName, "errorCount"));
-            writer.print(" " + args[8]);
+            writer.print(' ');
+            writer.print(args[8]);
+            writer.print(' ');
             writer.print(formatSize(mBeanServer.getAttribute
                                     (grpName, "bytesReceived"), true));
-            writer.print(" " + args[9]);
+            writer.print(' ');
+            writer.print(args[9]);
+            writer.print(' ');
             writer.print(formatSize(mBeanServer.getAttribute
                                     (grpName, "bytesSent"), true));
             writer.print("</p>");
@@ -513,7 +548,7 @@ public class StatusTransformer {
                 if (showRequest) {
                     writer.write(Escape.htmlElementContent(mBeanServer.getAttribute
                                         (pName, "method")));
-                    writer.write(" ");
+                    writer.write(' ');
                     writer.write(Escape.htmlElementContent(mBeanServer.getAttribute
                                         (pName, "currentUri")));
                     String queryString = (String) mBeanServer.getAttribute
@@ -522,7 +557,7 @@ public class StatusTransformer {
                         writer.write("?");
                         writer.print(Escape.htmlElementContent(queryString));
                     }
-                    writer.write(" ");
+                    writer.write(' ');
                     writer.write(Escape.htmlElementContent(mBeanServer.getAttribute
                                         (pName, "protocol")));
                 } else {
