@@ -38,6 +38,10 @@ public class MappingData {
     public Wrapper wrapper = null;
     public boolean jspWildCard = false;
 
+    /**
+     * @deprecated Unused. This will be removed in Tomcat 10.
+     */
+    @Deprecated
     public final MessageBytes contextPath = MessageBytes.newInstance();
     public final MessageBytes requestPath = MessageBytes.newInstance();
     public final MessageBytes wrapperPath = MessageBytes.newInstance();
@@ -45,7 +49,7 @@ public class MappingData {
 
     public final MessageBytes redirectPath = MessageBytes.newInstance();
 
-    // Fields used by ApplicationMapping to implement javax.servlet.http.Mapping
+    // Fields used by ApplicationMapping to implement javax.servlet.http.HttpServletMapping
     public MappingMatch matchType = null;
 
     public void recycle() {
