@@ -22,7 +22,6 @@ import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
-import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.security.Principal;
 import java.security.cert.X509Certificate;
@@ -40,6 +39,7 @@ import org.apache.catalina.Engine;
 import org.apache.catalina.Host;
 import org.apache.catalina.LifecycleException;
 import org.apache.catalina.LifecycleState;
+import org.apache.catalina.Realm;
 import org.apache.catalina.Server;
 import org.apache.catalina.Service;
 import org.apache.catalina.Wrapper;
@@ -47,11 +47,11 @@ import org.apache.catalina.connector.Request;
 import org.apache.catalina.connector.Response;
 import org.apache.catalina.util.LifecycleMBeanBase;
 import org.apache.catalina.util.SessionConfig;
+import org.apache.catalina.util.ToStringUtil;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.IntrospectionUtils;
 import org.apache.tomcat.util.buf.B2CConverter;
-import org.apache.tomcat.util.buf.HexUtils;
 import org.apache.tomcat.util.descriptor.web.SecurityCollection;
 import org.apache.tomcat.util.descriptor.web.SecurityConstraint;
 import org.apache.tomcat.util.res.StringManager;
@@ -69,8 +69,7 @@ import org.ietf.jgss.GSSName;
  *
  * @author Craig R. McClanahan
  */
-@SuppressWarnings("deprecation")
-public abstract class RealmBase extends LifecycleMBeanBase implements org.apache.catalina.GSSRealm {
+public abstract class RealmBase extends LifecycleMBeanBase implements Realm {
 
     private static final Log log = LogFactory.getLog(RealmBase.class);
 
@@ -409,8 +408,7 @@ public abstract class RealmBase extends LifecycleMBeanBase implements org.apache
         try {
             valueBytes = serverDigestValue.getBytes(getDigestCharset());
         } catch (UnsupportedEncodingException uee) {
-            log.error("Illegal digestEncoding: " + getDigestEncoding(), uee);
-            throw new IllegalArgumentException(uee.getMessage());
+            throw new IllegalArgumentException(sm.getString("realmBase.invalidDigestEncoding", getDigestEncoding()), uee);
         }
 
         String serverDigest = MD5Encoder.encode(ConcurrentMessageDigest.digestMD5(valueBytes));
@@ -1025,7 +1023,7 @@ public abstract class RealmBase extends LifecycleMBeanBase implements org.apache
             return true;
         }
         // Initialize variables we need to determine the appropriate action
-        int redirectPort = request.getConnector().getRedirectPort();
+        int redirectPort = request.getConnector().getRedirectPortWithOffset();
 
         // Is redirecting disabled?
         if (redirectPort <= 0) {
@@ -1084,11 +1082,6 @@ public abstract class RealmBase extends LifecycleMBeanBase implements org.apache
     }
 
 
-    @Override
-    public boolean isAvailable() {
-        return true;
-    }
-
     @Override
     protected void initInternal() throws LifecycleException {
 
@@ -1139,10 +1132,7 @@ public abstract class RealmBase extends LifecycleMBeanBase implements org.apache
      */
     @Override
     public String toString() {
-        StringBuilder sb = new StringBuilder("Realm[");
-        sb.append(getName());
-        sb.append(']');
-        return sb.toString();
+        return ToStringUtil.toString(this);
     }
 
 
@@ -1176,8 +1166,7 @@ public abstract class RealmBase extends LifecycleMBeanBase implements org.apache
         try {
             valueBytes = digestValue.getBytes(getDigestCharset());
         } catch (UnsupportedEncodingException uee) {
-            log.error("Illegal digestEncoding: " + getDigestEncoding(), uee);
-            throw new IllegalArgumentException(uee.getMessage());
+            throw new IllegalArgumentException(sm.getString("realmBase.invalidDigestEncoding", getDigestEncoding()), uee);
         }
 
         return MD5Encoder.encode(ConcurrentMessageDigest.digestMD5(valueBytes));
@@ -1203,17 +1192,6 @@ public abstract class RealmBase extends LifecycleMBeanBase implements org.apache
     }
 
 
-    /**
-     * @return a short name for this Realm implementation, for use in
-     * log messages.
-     *
-     * @deprecated This will be removed in Tomcat 9 onwards. Use
-     *             {@link Class#getSimpleName()} instead.
-     */
-    @Deprecated
-    protected abstract String getName();
-
-
     /**
      * Get the password for the specified user.
      * @param username The user name
@@ -1233,7 +1211,7 @@ public abstract class RealmBase extends LifecycleMBeanBase implements org.apache
         if(log.isDebugEnabled())
             log.debug(sm.getString("realmBase.gotX509Username", username));
 
-        return(getPrincipal(username));
+        return getPrincipal(username);
     }
 
 
@@ -1323,47 +1301,6 @@ public abstract class RealmBase extends LifecycleMBeanBase implements org.apache
 
     // --------------------------------------------------------- Static Methods
 
-    /**
-     * Digest password using the algorithm specified and convert the result to a
-     * corresponding hex string.
-     *
-     * @param credentials Password or other credentials to use in authenticating
-     *                    this username
-     * @param algorithm   Algorithm used to do the digest
-     * @param encoding    Character encoding of the string to digest
-     *
-     * @return The digested credentials as a hex string or the original plain
-     *         text credentials if an error occurs.
-     *
-     * @deprecated  Unused. This will be removed in Tomcat 9.
-     */
-    @Deprecated
-    public static final String Digest(String credentials, String algorithm,
-                                      String encoding) {
-
-        try {
-            // Obtain a new message digest with "digest" encryption
-            MessageDigest md =
-                (MessageDigest) MessageDigest.getInstance(algorithm).clone();
-
-            // encode the credentials
-            // Should use the digestEncoding, but that's not a static field
-            if (encoding == null) {
-                md.update(credentials.getBytes());
-            } else {
-                md.update(credentials.getBytes(encoding));
-            }
-
-            // Digest the credentials and return as hexadecimal
-            return (HexUtils.toHexString(md.digest()));
-        } catch(Exception ex) {
-            log.error(ex);
-            return credentials;
-        }
-
-    }
-
-
     /**
      * Generate a stored credential string for the given password and associated
      * parameters.
@@ -1576,7 +1513,8 @@ public abstract class RealmBase extends LifecycleMBeanBase implements org.apache
             } else if (name.equalsIgnoreCase(STRICT_AUTH_ONLY_MODE.name)) {
                 mode = STRICT_AUTH_ONLY_MODE;
             } else {
-                throw new IllegalStateException("Unknown mode, must be one of: strict, authOnly, strictAuthOnly");
+                throw new IllegalStateException(
+                        sm.getString("realmBase.unknownAllRolesMode", name));
             }
             return mode;
         }
