@@ -38,12 +38,12 @@ import org.apache.juli.logging.LogFactory;
  * and smaller messages can make it through.
  *
  * <br><b>Configuration Options</b><br>
- * OrderInterceptor.expire=&lt;milliseconds&gt; - how long do we keep the fragments in memory and wait for the rest to arrive<b>default=60,000ms -&gt; 60seconds</b>
+ * FragmentationInterceptor.expire=&lt;milliseconds&gt; - how long do we keep the fragments in memory and wait for the rest to arrive <b>default=60,000ms -&gt; 60seconds</b>
  * This setting is useful to avoid OutOfMemoryErrors<br>
- * OrderInterceptor.maxSize=&lt;max message size&gt; - message size in bytes <b>default=1024*100 (around a tenth of a MB)</b><br>
+ * FragmentationInterceptor.maxSize=&lt;max message size&gt; - message size in bytes <b>default=1024*100 (around a tenth of a MB)</b><br>
  * @version 1.0
  */
-public class FragmentationInterceptor extends ChannelInterceptorBase {
+public class FragmentationInterceptor extends ChannelInterceptorBase implements FragmentationInterceptorMBean {
     private static final Log log = LogFactory.getLog(FragmentationInterceptor.class);
     protected static final StringManager sm = StringManager.getManager(FragmentationInterceptor.class);
 
@@ -157,19 +157,22 @@ public class FragmentationInterceptor extends ChannelInterceptorBase {
         super.heartbeat();
     }
 
-
+    @Override
     public int getMaxSize() {
         return maxSize;
     }
 
+    @Override
     public long getExpire() {
         return expire;
     }
 
+    @Override
     public void setMaxSize(int maxSize) {
         this.maxSize = maxSize;
     }
 
+    @Override
     public void setExpire(long expire) {
         this.expire = expire;
     }
