@@ -115,10 +115,9 @@ public class TwoPhaseCommitInterceptor extends ChannelInterceptorBase {
             for (int i=0; i<entries.length; i++ ) {
                 MapEntry entry = entries[i].getValue();
                 if ( entry.expired(now,expire) ) {
-                    if(log.isInfoEnabled())
-                        log.info("Message ["+entry.id+"] has expired. Removing.");
+                    log.info(sm.getString("twoPhaseCommitInterceptor.expiredMessage", entry.id));
                     messages.remove(entry.id);
-                }//end if
+                }
             }
         } catch ( Exception x ) {
             log.warn(sm.getString("twoPhaseCommitInterceptor.heartbeat.failed"),x);
