@@ -22,16 +22,13 @@ package org.apache.catalina.util;
 public class TomcatCSS {
 
     public static final String TOMCAT_CSS =
-        "H1 {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;font-size:22px;} " +
-        "H2 {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;font-size:16px;} " +
-        "H3 {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;font-size:14px;} " +
-        "BODY {font-family:Tahoma,Arial,sans-serif;color:black;background-color:white;} " +
-        "B {font-family:Tahoma,Arial,sans-serif;color:white;background-color:#525D76;} " +
-        "P {font-family:Tahoma,Arial,sans-serif;background:white;color:black;font-size:12px;}" +
-        "A {color : black;}" +
-        "A.name {color : black;}" +
-        ".line {height: 1px; background-color: #525D76; border: none;}";
-
+        "body {font-family:Tahoma,Arial,sans-serif;} " +
+        "h1, h2, h3, b {color:white;background-color:#525D76;} " +
+        "h1 {font-size:22px;} " +
+        "h2 {font-size:16px;} " +
+        "h3 {font-size:14px;} " +
+        "p {font-size:12px;} " +
+        "a {color:black;} " +
+        ".line {height:1px;background-color:#525D76;border:none;}";
 
 }
-
