@@ -105,10 +105,7 @@ class TagLibraryInfoImpl extends TagLibraryInfo implements TagConstants {
         return sw.toString();
     }
 
-    /**
-     * Constructor.
-     */
-    @SuppressWarnings("null")  // taglibXml can't be null
+
     public TagLibraryInfoImpl(JspCompilationContext ctxt, ParserController pc,
             PageInfo pi, String prefix, String uriIn,
             TldResourcePath tldResourcePath, ErrorDispatcher err)
@@ -185,7 +182,11 @@ class TagLibraryInfoImpl extends TagLibraryInfo implements TagConstants {
             }
 
             // Populate the TagLibraryInfo attributes
-            this.jspversion = taglibXml.getJspVersion();
+            // Never null. jspError always throws an Exception
+            // Slightly convoluted so the @SuppressWarnings has minimal scope
+            @SuppressWarnings("null")
+            String v = taglibXml.getJspVersion();
+            this.jspversion = v;
             this.tlibversion = taglibXml.getTlibVersion();
             this.shortname = taglibXml.getShortName();
             this.urn = taglibXml.getUri();
@@ -289,7 +290,7 @@ class TagLibraryInfoImpl extends TagLibraryInfo implements TagConstants {
         if (teiClassName != null && !teiClassName.isEmpty()) {
             try {
                 Class<?> teiClass = ctxt.getClassLoader().loadClass(teiClassName);
-                tei = (TagExtraInfo) teiClass.newInstance();
+                tei = (TagExtraInfo) teiClass.getConstructor().newInstance();
             } catch (Exception e) {
                 err.jspError(e, "jsp.error.teiclass.instantiation", teiClassName);
             }
@@ -345,7 +346,7 @@ class TagLibraryInfoImpl extends TagLibraryInfo implements TagConstants {
 
         try {
             Class<?> tlvClass = ctxt.getClassLoader().loadClass(validatorClass);
-            TagLibraryValidator tlv = (TagLibraryValidator) tlvClass.newInstance();
+            TagLibraryValidator tlv = (TagLibraryValidator) tlvClass.getConstructor().newInstance();
             tlv.setInitParameters(initParams);
             return tlv;
         } catch (Exception e) {
