@@ -43,8 +43,12 @@ public class Import {
     private static void processFile(File f) throws IOException {
         String language = Utils.getLanguage(f.getName());
 
-        // Unlike the master branch, don't skip the original so we can import
-        // updates to the English translations
+        // Skip the original
+        if (language.length() == 0) {
+            // Comment this line out if the originals needs to be exported.
+            return;
+        }
+
         Properties props = Utils.load(f);
         Object[] objKeys = props.keySet().toArray();
         Arrays.sort(objKeys);
@@ -65,7 +69,7 @@ public class Import {
                 File outFile = new File(currentPkg.replace('.', File.separatorChar), Constants.L10N_PREFIX + language + Constants.L10N_SUFFIX);
                 FileOutputStream fos = new FileOutputStream(outFile);
                 w = new OutputStreamWriter(fos, StandardCharsets.UTF_8);
-                org.apache.tomcat.buildutil.Utils.insertLicense(w);
+                insertLicense(w);
             }
 
             if (!currentGroup.equals(cKey.group)) {
@@ -82,6 +86,36 @@ public class Import {
     }
 
 
+    private static void insertLicense(Writer w) throws IOException {
+        w.write("# Licensed to the Apache Software Foundation (ASF) under one or more");
+        w.write(System.lineSeparator());
+        w.write("# contributor license agreements.  See the NOTICE file distributed with");
+        w.write(System.lineSeparator());
+        w.write("# this work for additional information regarding copyright ownership.");
+        w.write(System.lineSeparator());
+        w.write("# The ASF licenses this file to You under the Apache License, Version 2.0");
+        w.write(System.lineSeparator());
+        w.write("# (the \"License\"); you may not use this file except in compliance with");
+        w.write(System.lineSeparator());
+        w.write("# the License.  You may obtain a copy of the License at");
+        w.write(System.lineSeparator());
+        w.write("#");
+        w.write(System.lineSeparator());
+        w.write("#     http://www.apache.org/licenses/LICENSE-2.0");
+        w.write(System.lineSeparator());
+        w.write("#");
+        w.write(System.lineSeparator());
+        w.write("# Unless required by applicable law or agreed to in writing, software");
+        w.write(System.lineSeparator());
+        w.write("# distributed under the License is distributed on an \"AS IS\" BASIS,");
+        w.write(System.lineSeparator());
+        w.write("# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.");
+        w.write(System.lineSeparator());
+        w.write("# See the License for the specific language governing permissions and");
+        w.write(System.lineSeparator());
+        w.write("# limitations under the License.");
+        w.write(System.lineSeparator());
+    }
     private static class CompositeKey {
 
         public final String pkg;
