@@ -191,7 +191,6 @@ public class CallParamRule extends Rule {
      */
     @Override
     public String toString() {
-
         StringBuilder sb = new StringBuilder("CallParamRule[");
         sb.append("paramIndex=");
         sb.append(paramIndex);
@@ -200,8 +199,7 @@ public class CallParamRule extends Rule {
         sb.append(", from stack=");
         sb.append(fromStack);
         sb.append("]");
-        return (sb.toString());
-
+        return sb.toString();
     }
 
 
