@@ -16,39 +16,30 @@
  */
 package org.apache.tomcat.util.net.openssl;
 
+import java.io.IOException;
+import java.security.KeyStoreException;
 import java.util.List;
 import java.util.Set;
 
 import javax.net.ssl.KeyManager;
-import javax.net.ssl.SSLSessionContext;
-import javax.net.ssl.TrustManager;
+import javax.net.ssl.X509KeyManager;
 
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
-import org.apache.tomcat.jni.SSL;
 import org.apache.tomcat.util.net.SSLContext;
-import org.apache.tomcat.util.net.SSLHostConfig;
 import org.apache.tomcat.util.net.SSLHostConfigCertificate;
 import org.apache.tomcat.util.net.SSLUtilBase;
-import org.apache.tomcat.util.net.jsse.JSSEUtil;
+import org.apache.tomcat.util.net.jsse.JSSEKeyManager;
+import org.apache.tomcat.util.res.StringManager;
 
 public class OpenSSLUtil extends SSLUtilBase {
 
     private static final Log log = LogFactory.getLog(OpenSSLUtil.class);
+    private static final StringManager sm = StringManager.getManager(OpenSSLContext.class);
 
-    private final JSSEUtil jsseUtil;
 
     public OpenSSLUtil(SSLHostConfigCertificate certificate) {
         super(certificate);
-
-        if (certificate.getCertificateFile() == null) {
-            // Using JSSE configuration for keystore and truststore
-            // Missing protocols not a concern so don't warn on skip
-            jsseUtil = new JSSEUtil(certificate, false);
-        } else {
-            // Use OpenSSL configuration for certificates
-            jsseUtil = null;
-        }
     }
 
 
@@ -70,12 +61,6 @@ public class OpenSSLUtil extends SSLUtilBase {
     }
 
 
-    @Override
-    protected boolean isTls13Available() {
-        return SSL.version() >= 0x1010100f;
-    }
-
-
     @Override
     protected boolean isTls13RenegAuthAvailable() {
         // OpenSSL does support authentication after the initial handshake
@@ -84,37 +69,60 @@ public class OpenSSLUtil extends SSLUtilBase {
 
 
     @Override
-    public SSLContext createSSLContext(List<String> negotiableProtocols) throws Exception {
+    public SSLContext createSSLContextInternal(List<String> negotiableProtocols) throws Exception {
         return new OpenSSLContext(certificate, negotiableProtocols);
     }
 
-    @Override
-    public KeyManager[] getKeyManagers() throws Exception {
-        if (jsseUtil != null) {
-            return jsseUtil.getKeyManagers();
-        } else {
-            // Return something although it is not actually used
-            KeyManager[] managers = {
-                    new OpenSSLKeyManager(SSLHostConfig.adjustRelativePath(certificate.getCertificateFile()),
-                            SSLHostConfig.adjustRelativePath(certificate.getCertificateKeyFile()))
-            };
-            return managers;
-        }
-    }
 
-    @Override
-    public TrustManager[] getTrustManagers() throws Exception {
-        if (jsseUtil != null) {
-            return jsseUtil.getTrustManagers();
-        } else {
+    public static X509KeyManager chooseKeyManager(KeyManager[] managers) throws Exception {
+        if (managers == null) {
             return null;
         }
+        for (KeyManager manager : managers) {
+            if (manager instanceof JSSEKeyManager) {
+                return (JSSEKeyManager) manager;
+            }
+        }
+        for (KeyManager manager : managers) {
+            if (manager instanceof X509KeyManager) {
+                return (X509KeyManager) manager;
+            }
+        }
+        throw new IllegalStateException(sm.getString("openssl.keyManagerMissing"));
     }
 
+
     @Override
-    public void configureSessionContext(SSLSessionContext sslSessionContext) {
-        if (jsseUtil != null) {
-            jsseUtil.configureSessionContext(sslSessionContext);
+    public KeyManager[] getKeyManagers() throws Exception {
+        try {
+            return super.getKeyManagers();
+        } catch (IllegalArgumentException e) {
+            // No (or invalid?) certificate chain was provided for the cert
+            String msg = sm.getString("openssl.nonJsseChain", certificate.getCertificateChainFile());
+            if (log.isDebugEnabled()) {
+                log.info(msg, e);
+            } else {
+                log.info(msg);
+            }
+            return null;
+        } catch (KeyStoreException | IOException e) {
+            // Depending on what is presented, JSSE may also throw
+            // KeyStoreException or IOException if it doesn't understand the
+            // provided file.
+            if (certificate.getCertificateFile() != null) {
+                String msg = sm.getString("openssl.nonJsseCertficate",
+                        certificate.getCertificateFile(), certificate.getCertificateKeyFile());
+                if (log.isDebugEnabled()) {
+                    log.info(msg, e);
+                } else {
+                    log.info(msg);
+                }
+                // Assume JSSE processing of the certificate failed, try again with OpenSSL
+                // without a key manager
+                return null;
+            }
+            throw e;
         }
     }
+
 }
