@@ -17,6 +17,7 @@
 package org.apache.tomcat.websocket.pojo;
 
 import java.util.Collections;
+import java.util.List;
 
 import javax.websocket.Decoder;
 import javax.websocket.DeploymentException;
@@ -32,7 +33,7 @@ import javax.websocket.Session;
 public class PojoEndpointClient extends PojoEndpointBase {
 
     public PojoEndpointClient(Object pojo,
-            Class<? extends Decoder>[] decoders) throws DeploymentException {
+            List<Class<? extends Decoder>> decoders) throws DeploymentException {
         setPojo(pojo);
         setMethodMapping(
                 new PojoMethodMapping(pojo.getClass(), decoders, null));
