@@ -30,6 +30,9 @@ import org.junit.Test;
 import org.apache.catalina.Context;
 import org.apache.catalina.startup.Tomcat;
 
+import trailers.ResponseTrailers;
+
+
 public class TestStream extends Http2TestBase {
 
     /*
@@ -75,6 +78,54 @@ public class TestStream extends Http2TestBase {
     }
 
 
+    @Test
+    public void testResponseTrailerFields() throws Exception {
+
+        enableHttp2();
+
+        Tomcat tomcat = getTomcatInstance();
+
+        Context ctxt = tomcat.addContext("", null);
+        Tomcat.addServlet(ctxt, "simple", new SimpleServlet());
+        ctxt.addServletMappingDecoded("/simple", "simple");
+        Tomcat.addServlet(ctxt, "trailers", new ResponseTrailers());
+        ctxt.addServletMappingDecoded("/trailers", "trailers");
+
+        tomcat.start();
+
+        openClientConnection();
+        doHttpUpgrade();
+        sendClientPreface();
+        validateHttp2InitialResponse();
+
+        byte[] frameHeader = new byte[9];
+        ByteBuffer headersPayload = ByteBuffer.allocate(128);
+        buildGetRequest(frameHeader, headersPayload, null, 3, "/trailers");
+        writeFrame(frameHeader, headersPayload);
+
+        // Headers
+        parser.readFrame(true);
+        // Body
+        parser.readFrame(true);
+        // Trailers
+        parser.readFrame(true);
+
+        Assert.assertEquals(
+                "3-HeadersStart\n" +
+                "3-Header-[:status]-[200]\n" +
+                "3-Header-[content-type]-[text/plain;charset=UTF-8]\n" +
+                "3-Header-[content-length]-[44]\n" +
+                "3-Header-[date]-[Wed, 11 Nov 2015 19:18:42 GMT]\n" +
+                "3-HeadersEnd\n" +
+                "3-Body-44\n" +
+                "3-HeadersStart\n" +
+                "3-Header-[x-trailer-2]-[Trailer value two]\n" +
+                "3-Header-[x-trailer-1]-[Trailer value one]\n" +
+                "3-HeadersEnd\n" +
+                "3-EndOfStream\n", output.getTrace());
+    }
+
+
     private static final class PathParam extends HttpServlet {
 
         private static final long serialVersionUID = 1L;
